==> pogamut-emohawk-ville-3.5.2-20130819.040212-108-sources.jar: cz/cuni/amis/pogamut/emohawkVille/agent/module/observationMemory/memorization/item/utensil/cookware/AbstractCookwareMemorization.java <==
package cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.utensil.cookware;

import java.util.Collection;

import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructorChainer;
import cz.cuni.amis.pogamut.emohawkRpgBase.agent.module.observationMemory.ObservationMemory;
import cz.cuni.amis.pogamut.emohawkRpgBase.agent.module.observationMemory.memorization.item.container.AbstractContainerItemMemorization;
import cz.cuni.amis.pogamut.emohawkRpgBase.agent.module.replication.image.item.IItem;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.ingredient.IIngredientMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.FoodTools;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.item.utensil.cookware.AbstractCookwareReplication;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.item.utensil.cookware.CookwareStats;

public abstract class AbstractCookwareMemorization
	<MemorizedClass extends AbstractCookwareReplication>
	extends AbstractContainerItemMemorization<MemorizedClass> 
	implements ICookwareMemorization<MemorizedClass> {

	protected CookwareStats stats;
	protected float temperature;
	
	public AbstractCookwareMemorization( 
		MemorizedClass object,
		ObservationMemory observationMemory,
		CookwareStats stats,
		IDeferredConstructorChainer deferredConstructorChainer
	) {
		super(object, observationMemory, deferredConstructorChainer );
		temperature = object.getTemperature();
		this.stats = stats;
	}
	
	@Override
	public float getTemperature() {
		return temperature;
	}
	
	@Override
	public Collection<? extends IIngredientMemorization<?>> readIngredients() {
		return FoodTools.readIngredients( readInventory() );
	}
	
	@Override
	public boolean canStore( IItem item ) {
		return FoodTools.canStoreFood( readIngredients(), item, stats.getFoodCapacity() );
	}
	
	@Override
	public boolean canRelease( IItem item ) {
		return false;
	}
}

==> pogamut-emohawk-ville-3.5.4-20140115.043800-30-sources.jar: cz/cuni/amis/pogamut/emohawkVille/agent/module/observationMemory/memorization/item/utensil/cookware/AbstractCookwareMemorization.java <==
package cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.utensil.cookware;

import java.util.Collection;

import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructorChainer;
import cz.cuni.amis.pogamut.emohawkRpgBase.agent.module.observationMemory.ObservationMemory;
import cz.cuni.amis.pogamut.emohawkRpgBase.agent.module.observationMemory.memorization.item.container.AbstractContainerItemMemorization;
import cz.cuni.amis.pogamut.emohawkRpgBase.agent.module.replication.image.item.IItem;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.ingredient.IIngredientMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.FoodTools;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.item.utensil.cookware.AbstractCookwareReplica;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.item.utensil.cookware.CookwareStats;

public abstract class AbstractCookwareMemorization
	<MemorizedClass extends AbstractCookwareReplica>
	extends AbstractContainerItemMemorization<MemorizedClass> 
	implements ICookwareMemorization<MemorizedClass> {

	protected CookwareStats stats;
	protected float temperature;
	
	public AbstractCookwareMemorization( 
		MemorizedClass object,
		ObservationMemory observationMemory,
		CookwareStats stats,
		IDeferredConstructorChainer deferredConstructorChainer
	) {
		super(object, observationMemory, deferredConstructorChainer );
		temperature = object.getTemperature();
		this.stats = stats;
	}
	
	@Override
	public float getTemperature() {
		return temperature;
	}
	
	@Override
	public Collection<? extends IIngredientMemorization<?>> readIngredients() {
		return FoodTools.readIngredients( readInventory() );
	}
	
	@Override
	public boolean canStore( IItem item ) {
		return FoodTools.canStoreFood( readIngredients(), item, stats.getFoodCapacity() );
	}
	
	@Override
	public boolean canRelease( IItem item ) {
		return false;
	}
}
